sage_flatsurf: Flat surfaces in SageMath
========================================

Description
-----------

SageMath package for studying the geometry of flat surfaces and the
dynamics of their foliations.

License
-------

GNU General Public License, version 2

Upstream Contact
----------------

https://pypi.org/project/sage-flatsurf/

